/*!
 * @file        main.c
 *
 * @brief       Main program body
 *
 * @version     V1.0.0
 *
 * @date        2023-03-30
 *
 * @attention
 *
 *  Copyright (C) 2023 Geehy Semiconductor
 *
 *  You may not use this file except in compliance with the
 *  GEEHY COPYRIGHT NOTICE (GEEHY SOFTWARE PACKAGE LICENSE).
 *
 *  The program is only for reference, which is distributed in the hope
 *  that it will be useful and instructional for customers to develop
 *  their software. Unless required by applicable law or agreed to in
 *  writing, the program is distributed on an "AS IS" BASIS, WITHOUT
 *  ANY WARRANTY OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the GEEHY SOFTWARE PACKAGE LICENSE for the governing permissions
 *  and limitations under the License.
 */

/* Includes */
#include "main.h"

/** @addtogroup Examples
  @{
  */

/** @addtogroup Flash_Emulation_Eeprom
  @{
  */

/** @defgroup Flash_Emulation_Eeprom_Macros Macros
  @{
*/

#define BUFFER_SIZE  64
#define DEBUG_USART  USART1
#define FLASH_EE_TEST_ADDR  ((uint32_t)0x08007FF0)

/**@} end of group Flash_Emulation_Eeprom_Macros*/

/** @defgroup Flash_Emulation_Eeprom_Variables Variables
  @{
*/

/* test write buffer */
static uint16_t Test_Write_buffer[BUFFER_SIZE];

/* test read buffer */
static uint16_t Test_Read_buffer[BUFFER_SIZE];

/**@} end of group Flash_Emulation_Eeprom_Variables */

/** @defgroup Flash_Emulation_Eeprom_Functions Functions
  @{
*/

/*!
 * @brief       Main program
 *
 * @param       None
 *
 * @retval      None
 *
 */
int main(void)
{
    /* COM1 init*/
    APM_MINI_COMInit(COM1);
    
    printf("\r\nThis is an example of flash emulation eeprom.\r\n");
    
    /* fill Test_Write_buffer */
    for (int i=0; i<BUFFER_SIZE; i++)
    {
        Test_Write_buffer[i] = i;
    }
    
    /* write the specified sector address data */
    Flash_EE_Write(FLASH_EE_TEST_ADDR, Test_Write_buffer, BUFFER_SIZE);
    
    /* read the specified sector address data */
    Flash_EE_Read(FLASH_EE_TEST_ADDR, Test_Read_buffer, BUFFER_SIZE);
    
    /* compare the values of two buffers for equality */
    for (int i=0; i<BUFFER_SIZE; i++)
    {
        if (Test_Write_buffer[i] != Test_Read_buffer[i])
        {
            printf("Test Error!\r\n");
            break;
        }
    }
    
    printf("Test Successful!\r\n");
    
    while (1)
    {
    }
}

#if defined (__CC_ARM) || defined (__ICCARM__) || (defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050))

/*!
* @brief       Redirect C Library function printf to serial port.
*              After Redirection, you can use printf function.
*
* @param       ch:  The characters that need to be send.
*
* @param       *f:  pointer to a FILE that can recording all information
*              needed to control a stream
*
* @retval      The characters that need to be send.
*
* @note
*/
int fputc(int ch, FILE *f)
{
    /* send a byte of data to the serial port */
    USART_TxData(DEBUG_USART, (uint8_t)ch);

    /* wait for the data to be send  */
    while (USART_ReadStatusFlag(DEBUG_USART, USART_FLAG_TXBE) == RESET);

    return (ch);
}

#elif defined (__GNUC__)

/*!
* @brief       Redirect C Library function printf to serial port.
*              After Redirection, you can use printf function.
*
* @param       ch:  The characters that need to be send.
*
* @retval      The characters that need to be send.
*
* @note
*/
int __io_putchar(int ch)
{
    /* send a byte of data to the serial port */
    USART_TxData(DEBUG_USART, ch);

    /* wait for the data to be send  */
    while (USART_ReadStatusFlag(DEBUG_USART, USART_FLAG_TXBE) == RESET);

    return ch;
}

/*!
* @brief       Redirect C Library function printf to serial port.
*              After Redirection, you can use printf function.
*
* @param       file:  Meaningless in this function.
*
* @param       *ptr:  Buffer pointer for data to be sent.
*
* @param       len:  Length of data to be sent.
*
* @retval      The characters that need to be send.
*
* @note
*/
int _write(int file, char *ptr, int len)
{
    int i;
    for (i = 0; i < len; i++)
    {
        __io_putchar(*ptr++);
    }

    return len;
}

#else
#warning Not supported compiler type
#endif

/**@} end of group Flash_Emulation_Eeprom_Functions */
/**@} end of group Flash_Emulation_Eeprom */
/**@} end of group Examples */
